@@ -1,5 +1,5 @@
 #!/bin/bash 
-#   Copyright (C) 2004-2015 Remik Ziemlinski @ noaa gov
+#   Copyright (C) 2004-2015 remik @ fastmail . com
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 if [ $# -lt 2 ]
 then
-    echo "Usage : $0 [compound|encoding|group|missing|nan|NUMBER|pad] <id>"
+    echo "Usage : $0 [compound|encoding|group|missing|nan|NUMBER|pad|subgroups] <id>"
     echo
     echo "Examples:"
     echo "  $0 21 68  # Will generate files test21{a,b}.68.nc"
@@ -47,7 +47,11 @@ function format() {
     NC_FORMATS=$($srcdir/ncgen_formats.sh $ID)
     NC3=$(echo $NC_FORMATS | cut -f1 -d' ')
     NC4=$(echo $NC_FORMATS | cut -f2 -d' ')
-    FMT=(0 $NC3 $NC3 $NC3 $NC3 $NC3 $NC3 $NC3 $NC3 $NC3 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4 $NC4)
+    FMT=(0    $NC3 $NC3 $NC3 $NC3
+         $NC3 $NC3 $NC3 $NC3 $NC3
+         $NC4 $NC4 $NC4 $NC4 $NC4
+         $NC4 $NC4 $NC4 $NC4 $NC4
+         $NC4 $NC4 $NC4 $NC4 $NC3)
     
     echo ${FMT[${index}]}
 }
@@ -108,13 +112,19 @@ case "$DATA" in
         ./padheader unpadded.$ID.nc 0 
         ./padheader padded.$ID.nc 2048
         ;;
-    *) 
+    subgroups)
+        echo For subgroup tests, require nc4.
+        fmt=$(format 10 $ID)
+        $NCGEN -k $fmt -o subgroups1a.$ID.nc -x $srcdir/subgroups1a.cdl
+        $NCGEN -k $fmt -o subgroups1b.$ID.nc -x $srcdir/subgroups1b.cdl
+        ;;
+    *)
         echo Create basic netcdf test files with ncgen.
         for SUFFIX in a b; do
             # Check for backwards compatible test files. 
             PATCH=""
             NCGEN_VER=$(ncgen_version)
-            if [ ${NCGEN_VER:0:5} != "4.3.3" ]; then
+            if [[ ${NCGEN_VER:0:5} < "4.3.3" ]]; then
                 if [ -e test${DATA}${SUFFIX}.pre433.cdl ]; then
                     PATCH=.pre433
                 elif [ -e test${DATA}${SUFFIX}.pre413.cdl ]; then
