@@ -6,7 +6,7 @@ $srcdir/test_nccmp_setup.sh $DATA $I
 TRUTH=$srcdir/stderr$I.txt
 NCGEN_VER=$(ncgen -v 2>&1 | grep -e version | cut -d' ' -f4)
 
-if [ ${NCGEN_VER:0:5} != "4.3.3" ]; then
+if [[ ${NCGEN_VER:0:5} < "4.3.3" ]]; then
     LEGACY_TRUTH=$srcdir/stderr$I.pre433.txt
     if [ -e $LEGACY_TRUTH ]; then
         TRUTH=$LEGACY_TRUTH
